@@ -36,6 +36,7 @@ fn main() {
                 }
 
                 // Explicit cancelation example:
+                // Check if the current flower should be canceled
                 if handle.should_cancel() {
                     let value = format!("canceling the flower with id: {}", id);
                     handle.send(value);
@@ -60,10 +61,9 @@ fn main() {
                 //     flower.cancel();
                 // }
                 let mut done = false;
+
                 flower.try_recv(
-                    |value| {
-                        println!("{}\n", value);
-                    },
+                    |value| println!("{}\n", value),
                     |result| {
                         match result {
                             Ok(elapsed) => println!(
